#[non_exhaustive]pub enum HeaderError {
Reserved {
key: String,
},
EmptyKey,
ControlCharacterInKey {
key: String,
},
ControlCharacterInValue {
key: String,
},
KeyTooLong {
len: usize,
},
ValueTooLong {
len: usize,
},
TooManyHeaders {
limit: usize,
},
}Expand description
Headers::insert failures.
use reliar_core::{HeaderError, Headers};
let mut headers = Headers::default();
let err = headers.insert("reliar-anything", "nope").unwrap_err();
assert!(matches!(err, HeaderError::Reserved { .. }));Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Reserved
The key starts with the reserved reliar- prefix (case-insensitive).
EmptyKey
The key was empty.
ControlCharacterInKey
The key contained a control character (including CR/LF — a header-injection surface).
ControlCharacterInValue
The value for this key contained a control character (including CR/LF). The value itself is never carried on the error — it may be a secret; the key is, so the caller can tell which header was rejected.
KeyTooLong
The key exceeded Headers::MAX_KEY_LEN.
ValueTooLong
The value exceeded Headers::MAX_VALUE_LEN.
TooManyHeaders
Inserting a new key would exceed Headers::MAX_COUNT.