#[non_exhaustive]pub enum IdError {
Empty,
TooLong {
len: usize,
max: usize,
},
ControlCharacter,
}Expand description
Validation failures shared by every capped string identity newtype in reliar-core.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Empty
The value was empty.
TooLong
The value exceeded its type’s maximum length.
Fields
ControlCharacter
The value contained a control character (including CR/LF) — a header-injection surface once a mapper writes this value onto the wire.